@@ -15,7 +15,8 @@
 #' @examples
 #' library("sf")
 #' ger   <- st_read(system.file("shape/GermanyNUTS3.shp",
-#'                              package = "SDPDmod"))
+#'                              package = "SDPDmod"),
+#'                  quiet = TRUE)
 #' W     <- mOrdNbr(ger, 3)
 #' Wnor  <- rownor(W)
 #'
@@ -23,11 +24,20 @@
 
 rownor<-function(W){
   if(nrow(W)!=ncol(W)) stop("Error in matrix!")
-  N<-nrow(W)
-  if(all(rowSums(W)!=0)) { W<-W/rowSums(W)
+  N <- nrow(W)
+  Wn <- matrix(NA,N,N)
+  if(all(rowSums(W)!=0)) {
+    Wn<-W/rowSums(W)
   } else {
-    message("Zero row in matrix.")
+    warning("Zero row in matrix.")
+    for(i in 1:N){
+      if(sum(W[i,])!=0) {
+        Wn[i,]<-W[i,]/sum(W[i,])
+      }else{
+        Wn[i,]<-0
+      }
+    }
   }
 
-  return(W)
+  return(Wn)
 }
